package Logfile::EPrints::Hit::Negate;

=head1 NAME

Logfile::EPrints::Hit::Negate - filter to remove existing hits

=head1 DESCRIPTION

Warning! Alpha! Liable to change!

=cut

use strict;

our @ISA = qw( Logfile::EPrints::Hit );

1;
