package Logfile::EPrints::Mapping;

1;

__END__

=head1 NAME

Logfile::EPrints::Mapping - map URLs to repository behaviour

=head1 DESCRIPTION

The following mappings are available:

=head2 Logfile::EPrints::Mapping::arXiv

Supports abstract and fulltext.

=head2 Logfile::EPrints::Mapping::DSpace

Supports abstract and fulltext.

=head2 Logfile::EPrints::Mapping::EPrints

Supports abstract, fulltext, browse and search.

=head1 SEE ALSO

L<Logfile::EPrints>, L<Logfile::EPrints::Mapping::arXiv>, L<Logfile::EPrints::Mapping::DSpace>, L<Logfile::EPrints::Mapping::EPrints>.
